# Subcommands

This section provides detailed documentation for each subcommand in
MACS3. Use `macs3 --help` to see the list of subcommands.

```{toctree}
:maxdepth: 2

callpeak.md
callvar.md
hmmratac.md
bdgbroadcall.md
bdgcmp.md
bdgdiff.md
bdgopt.md
bdgpeakcall.md
cmbreps.md
filterdup.md
pileup.md
predictd.md
randsample.md
refinepeak.md
